@@ -260,7 +260,6 @@ class MessageProcessor:
                         self.credentials[msgID] = credentials
 
                     self.outstanding[msgID] = entry
-                    #print(f"Caching message {msgID}")
                     return msgID
 
             retry += 1
@@ -276,11 +275,7 @@ class MessageProcessor:
             try:
                 del self.outstanding[msgID]
             except KeyError:
-                print(f"Tried to delete a nonexistent msgID: {msgID}")
                 pass
-            #else:
-            #    print(f"Un-caching message {msgID}")
-            #    print(f"The cache contains {len(self.outstanding)} messages")
 
     def secure(self, module, default=False):
         with self.securityLock:
@@ -382,9 +377,6 @@ class MessageProcessor:
         header = Integer(self.VERSION).encode() + msgGlobalData.encode()
         scopedPDU = ScopedPDU(pdu, engineID, contextName=contextName)
 
-        #print(msgGlobalData)
-        #print(scopedPDU)
-
         return securityModule.prepareOutgoing(
             header,
             scopedPDU.encode(),
